summaryrefslogtreecommitdiffstats
path: root/webkit/blob/blob_storage_controller.h
diff options
context:
space:
mode:
Diffstat (limited to 'webkit/blob/blob_storage_controller.h')
-rw-r--r--webkit/blob/blob_storage_controller.h13
1 files changed, 5 insertions, 8 deletions
diff --git a/webkit/blob/blob_storage_controller.h b/webkit/blob/blob_storage_controller.h
index fddd6ff..a32fab3 100644
--- a/webkit/blob/blob_storage_controller.h
+++ b/webkit/blob/blob_storage_controller.h
@@ -13,7 +13,6 @@
#include "base/process.h"
#include "webkit/blob/blob_data.h"
#include "webkit/blob/blob_export.h"
-#include "webkit/glue/resource_request_body.h"
class GURL;
class FilePath;
@@ -21,9 +20,8 @@ class FilePath;
namespace base {
class Time;
}
-
-namespace webkit_glue {
-class ResourceRequestBody;
+namespace net {
+class UploadData;
}
namespace webkit_blob {
@@ -42,10 +40,9 @@ class BLOB_EXPORT BlobStorageController {
void RemoveBlob(const GURL& url);
BlobData* GetBlobDataFromUrl(const GURL& url);
- // If there is any blob reference in the resource request body, it will get
- // resolved and updated in place.
- void ResolveBlobReferencesInRequestBody(
- webkit_glue::ResourceRequestBody* request_body);
+ // If there is any blob reference in the upload data, it will get resolved
+ // and updated in place.
+ void ResolveBlobReferencesInUploadData(net::UploadData* upload_data);
private:
friend class ViewBlobInternalsJob;